changeset 23280:9a0e33470da5

use "run-time condition" consistently in previous change * __run_test_suite__.m, test.m: Spell run-time consistently.
author John W. Eaton <jwe@octave.org>
date Wed, 15 Mar 2017 16:09:57 -0400
parents 67d741321e21
children 3cbd3caf19a7
files scripts/testfun/__run_test_suite__.m scripts/testfun/test.m
diffstat 2 files changed, 9 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/scripts/testfun/__run_test_suite__.m	Wed Mar 15 16:02:06 2017 -0400
+++ b/scripts/testfun/__run_test_suite__.m	Wed Mar 15 16:09:57 2017 -0400
@@ -74,16 +74,16 @@
       endfor
       puts ("\nSummary:\n\n");
       nfail = dn - dp - dxf;
-      printf ("  PASS                   %6d\n", dp);
-      printf ("  FAIL                   %6d\n", nfail);
+      printf ("  PASS                         %6d\n", dp);
+      printf ("  FAIL                         %6d\n", nfail);
       if (dxf > 0)
-        printf ("  XFAIL                  %6d\n", dxf);
+        printf ("  XFAIL                        %6d\n", dxf);
       endif
       if (dsk > 0)
-        printf ("  SKIPPED (feature)      %6d\n", dsk);
+        printf ("  SKIPPED (feature)            %6d\n", dsk);
       endif
       if (drtsk > 0)
-        printf ("  SKIPPED (runtime test) %6d\n", drtsk);
+        printf ("  SKIPPED (run-time condition) %6d\n", drtsk);
       endif
       puts ("\n");
       printf ("See the file %s for additional details.\n", logfile);
@@ -150,10 +150,10 @@
       printf ("\n%71s %3d", "FAIL ", nfail);
     endif
     if (sk > 0)
-      printf ("\n%71s %3d", "(feature) SKIP ", sk);
+      printf ("\n%71s %3d", "(missing feature) SKIP ", sk);
     endif
     if (rtsk > 0)
-      printf ("\n%71s %3d", "(runtime test) SKIP ", rtsk);
+      printf ("\n%71s %3d", "(run-time condition) SKIP ", rtsk);
     endif
     if (xf > 0)
       printf ("\n%71s %3d", "XFAIL", xf);
--- a/scripts/testfun/test.m	Wed Mar 15 16:02:06 2017 -0400
+++ b/scripts/testfun/test.m	Wed Mar 15 16:09:57 2017 -0400
@@ -83,7 +83,7 @@
 ## the total number of tests in the file (@var{nmax}), the number of xtest
 ## failures (@var{nxfail}), the number of tests skipped due to missing
 ## features (@var{nskip}), and the number of tests skipped due to
 ## runtime conditions (@var{nrtskip}) are returned.
 ##
 ## Example
 ##
@@ -714,7 +714,7 @@
                 ifelse (__xskip > 1, "s", ""));
       endif
       if (__xrtskip)
-        printf ("Skipped %d test%s due to runtime tests\n", __xrtskip,
+        printf ("Skipped %d test%s due to run-time conditions\n", __xrtskip,
                 ifelse (__xrtskip > 1, "s", ""));
       endif
     else
@@ -83,7 +83,7 @@
 ## failures (@var{nxfail}), the number of tests skipped due to missing
 ## features (@var{nskip}), and the number of tests skipped due to
-## runtime conditions (@var{nrtskip}) are returned.
+## run-time conditions (@var{nrtskip}) are returned.
 ##
 ## Example